pub struct ColorEditFlags(/* private fields */);Expand description
Dear ImGui (ImGuiColorEditFlags): Flags for ColorEdit4(), ColorPicker4() etc.
Implementations
Sourceimpl ColorEditFlags
impl ColorEditFlags
Sourcepub const NoAlpha: Self
pub const NoAlpha: Self
Dear ImGui (ImGuiColorEditFlags_NoAlpha): ColorEdit, ColorPicker, ColorButton: ignore Alpha component (will only read 3 components from the input pointer).
Sourcepub const NoPicker: Self
pub const NoPicker: Self
Dear ImGui (ImGuiColorEditFlags_NoPicker): ColorEdit: disable picker when clicking on color square.
Sourcepub const NoOptions: Self
pub const NoOptions: Self
Dear ImGui (ImGuiColorEditFlags_NoOptions): ColorEdit: disable toggling options menu when right-clicking on inputs/small preview.
Sourcepub const NoSmallPreview: Self
pub const NoSmallPreview: Self
Dear ImGui (ImGuiColorEditFlags_NoSmallPreview): ColorEdit, ColorPicker: disable color square preview next to the inputs. (e.g. to show only the inputs)
Sourcepub const NoInputs: Self
pub const NoInputs: Self
Dear ImGui (ImGuiColorEditFlags_NoInputs): ColorEdit, ColorPicker: disable inputs sliders/text widgets (e.g. to show only the small preview color square).
Sourcepub const NoTooltip: Self
pub const NoTooltip: Self
Dear ImGui (ImGuiColorEditFlags_NoTooltip): ColorEdit, ColorPicker, ColorButton: disable tooltip when hovering the preview.
Sourcepub const NoLabel: Self
pub const NoLabel: Self
Dear ImGui (ImGuiColorEditFlags_NoLabel): ColorEdit, ColorPicker: disable display of inline text label (the label is still forwarded to the tooltip and picker).
Sourcepub const NoSidePreview: Self
pub const NoSidePreview: Self
Dear ImGui (ImGuiColorEditFlags_NoSidePreview): ColorPicker: disable bigger color preview on right side of the picker, use small color square preview instead.
Sourcepub const NoDragDrop: Self
pub const NoDragDrop: Self
Dear ImGui (ImGuiColorEditFlags_NoDragDrop): ColorEdit: disable drag and drop target/source. ColorButton: disable drag and drop source.
Sourcepub const NoBorder: Self
pub const NoBorder: Self
Dear ImGui (ImGuiColorEditFlags_NoBorder): ColorButton: disable border (which is enforced by default)
Sourcepub const NoColorMarkers: Self
pub const NoColorMarkers: Self
Dear ImGui (ImGuiColorEditFlags_NoColorMarkers): ColorEdit: disable rendering R/G/B/A color marker.
Sourcepub const AlphaOpaque: Self
pub const AlphaOpaque: Self
Dear ImGui (ImGuiColorEditFlags_AlphaOpaque): ColorEdit, ColorPicker, ColorButton: disable alpha in the preview,. Contrary to _NoAlpha it may still be edited when calling ColorEdit4()/ColorPicker4().
Sourcepub const AlphaNoBg: Self
pub const AlphaNoBg: Self
Dear ImGui (ImGuiColorEditFlags_AlphaNoBg): ColorEdit, ColorPicker, ColorButton: disable rendering a checkerboard background behind transparent color.
Sourcepub const AlphaPreviewHalf: Self
pub const AlphaPreviewHalf: Self
Dear ImGui (ImGuiColorEditFlags_AlphaPreviewHalf): ColorEdit, ColorPicker, ColorButton: display half opaque / half transparent preview.
Sourcepub const AlphaBar: Self
pub const AlphaBar: Self
Dear ImGui (ImGuiColorEditFlags_AlphaBar): ColorEdit, ColorPicker: show vertical alpha bar/gradient in picker.
Sourcepub const HDR: Self
pub const HDR: Self
Dear ImGui (ImGuiColorEditFlags_HDR): (WIP) ColorEdit: Currently only disable 0.0f..1.0f limits in RGBA edition (note: you probably want to use ImGuiColorEditFlags_Float flag as well).
Sourcepub const DisplayRGB: Self
pub const DisplayRGB: Self
Dear ImGui (ImGuiColorEditFlags_DisplayRGB): ColorEdit: override display type among RGB/HSV/Hex. ColorPicker: select any combination using one or more of RGB/HSV/Hex.
Sourcepub const DisplayHSV: Self
pub const DisplayHSV: Self
Dear ImGui (ImGuiColorEditFlags_DisplayHSV): [Display] // “
Sourcepub const DisplayHex: Self
pub const DisplayHex: Self
Dear ImGui (ImGuiColorEditFlags_DisplayHex): [Display] // “
Sourcepub const Uint8: Self
pub const Uint8: Self
Dear ImGui (ImGuiColorEditFlags_Uint8): ColorEdit, ColorPicker, ColorButton: display values formatted as 0..255.
Sourcepub const Float: Self
pub const Float: Self
Dear ImGui (ImGuiColorEditFlags_Float): ColorEdit, ColorPicker, ColorButton: display values formatted as 0.0f..1.0f floats instead of 0..255 integers.
Sourcepub const PickerHueBar: Self
pub const PickerHueBar: Self
Dear ImGui (ImGuiColorEditFlags_PickerHueBar): ColorPicker: bar for Hue, rectangle for Sat/Value.
Sourcepub const PickerHueWheel: Self
pub const PickerHueWheel: Self
Dear ImGui (ImGuiColorEditFlags_PickerHueWheel): ColorPicker: wheel for Hue, triangle for Sat/Value.
Sourcepub const PickerNoRotate: Self
pub const PickerNoRotate: Self
Dear ImGui (ImGuiColorEditFlags_PickerNoRotate): ColorPicker: disable rotating Sat/Value triangle
Sourcepub const InputRGB: Self
pub const InputRGB: Self
Dear ImGui (ImGuiColorEditFlags_InputRGB): ColorEdit, ColorPicker: input and output data in RGB format.
Sourcepub const InputHSV: Self
pub const InputHSV: Self
Dear ImGui (ImGuiColorEditFlags_InputHSV): ColorEdit, ColorPicker: input and output data in HSV format.
Sourcepub const DefaultOptions_: Self
pub const DefaultOptions_: Self
Dear ImGui (ImGuiColorEditFlags_DefaultOptions_): Default options
Sourceimpl ColorEditFlags
impl ColorEditFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ColorEditFlags
impl ColorEditFlags
Sourcepub const fn iter(&self) -> Iter<ColorEditFlags>
pub const fn iter(&self) -> Iter<ColorEditFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ColorEditFlags>
pub const fn iter_names(&self) -> IterNames<ColorEditFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.